configs = {
    'mysql': {
        'host': '127.0.0.1',
        'port': 3306,
        'user': 'root',
        'password': 'root',
        'database': 'hotelindex',
        'wyn88_hotel_tab_name':'wyn88_hotel',
        'wyn88_room_price_tab_name': 'wyn88_room_price'
    }
}